Commit 2c75b00f authored by Mihai Moldovan's avatar Mihai Moldovan

nxcomp: Hardcode X11 and (legacy/xfs) font UNIX paths.

Fixes: ArcticaProject/nx-libs#536 Allowing overrides via NX_TEMP and TEMP breaks system using pam_tmpdir.so and most server infrastructure expects the location to be fixed anyway. Backported from Arctica GH 3.6.x branch. v2: backport to nx-libs 3.5.0.x (Mihai Moldovan) Adds: - debian/patches/1610_nxcomp-harcode-some-UNIX-socket-path.full+lite.patch
parent e095b8f6
......@@ -60,6 +60,15 @@ nx-libs (2:3.5.0.33-0x2go1) UNRELEASED; urgency=low
v2: backport to nx-libs 3.5.0.x (Mihai Moldovan)
Adds:
- debian/patches/1600_nxcomp-handle-launchd-socket-in-Auth.full+lite.patch
* nxcomp: Hardcode X11 and (legacy/xfs) font UNIX paths.
Fixes: ArcticaProject/nx-libs#536
Allowing overrides via NX_TEMP and TEMP breaks system using
pam_tmpdir.so and most server infrastructure expects the location to be
fixed anyway.
Backported from Arctica GH 3.6.x branch.
v2: backport to nx-libs 3.5.0.x (Mihai Moldovan)
Adds:
- debian/patches/1610_nxcomp-harcode-some-UNIX-socket-path.full+lite.patch
[ Mike Gabriel ]
* debian/libxinerama1.postinst.in:
......
From db1c2fbc5aaace3443cdecf4a1e34644f8f5f1fc Mon Sep 17 00:00:00 2001
From: Mihai Moldovan <ionic@ionic.de>
Date: Fri, 3 Nov 2017 12:57:25 +0100
Subject: [PATCH] nxcomp/src/Loop.cpp: hardcode X11 and (legacy/xfs) font UNIX
paths.
Fixes: ArcticaProject/nx-libs#536
Allowing overrides via NX_TEMP and TEMP breaks system using
pam_tmpdir.so and most server infrastructure expects the location to be
fixed anyway.
Backported from Arctica GH 3.6.x branch.
v2: backport to nx-libs 3.5.0.x (Mihai Moldovan)
---
nxcomp/src/Loop.cpp | 18 +++++-------------
1 file changed, 5 insertions(+), 13 deletions(-)
--- a/nxcomp/Loop.cpp
+++ b/nxcomp/Loop.cpp
@@ -4029,8 +4029,7 @@ int SetupUnixSocket()
char dirName[DEFAULT_STRING_LENGTH];
- snprintf(dirName, DEFAULT_STRING_LENGTH - 1, "%s/.X11-unix",
- control -> TempPath);
+ snprintf(dirName, DEFAULT_STRING_LENGTH - 1, "/tmp/.X11-unix");
*(dirName + DEFAULT_STRING_LENGTH - 1) = '\0';
@@ -4295,8 +4294,7 @@ int SetupDisplaySocket(int &xServerAddrF
char unixSocketDir[DEFAULT_STRING_LENGTH];
- snprintf(unixSocketDir, DEFAULT_STRING_LENGTH - 1, "%s/.X11-unix",
- control -> TempPath);
+ snprintf(unixSocketDir, DEFAULT_STRING_LENGTH - 1, "/tmp/.X11-unix");
#ifdef __APPLE__
@@ -13761,14 +13759,14 @@ int ParseFontPath(char *path)
//
// Let's assume that a port specification "unix/:7100"
// corresponds to "$TEMP/.font-unix/fs7100" and a port
// "unix/:-1" corresponds to "$TEMP/.font-unix/fs-1".
//
if (strncmp("unix/:", path, 6) == 0)
{
- snprintf(path, DEFAULT_STRING_LENGTH - 1, "%s/.font-unix/fs%s",
- control -> TempPath, oldPath + 6);
+ snprintf(path, DEFAULT_STRING_LENGTH - 1, "/tmp/.font-unix/fs%s",
+ oldPath + 6);
*(path + DEFAULT_STRING_LENGTH - 1) = '\0';
......@@ -153,6 +153,7 @@
1400_nx-X11_Render.c-Improve-situation-fo.full+lite.patch
@@ -13761,14 +13759,14 @@ int ParseFontPath(char *path)
//
// Let's assume that a port specification "unix/:7100"
- // corresponds to "$TEMP/.font-unix/fs7100" and a port
- // "unix/:-1" corresponds to "$TEMP/.font-unix/fs-1".
+ // corresponds to "/tmp/.font-unix/fs7100" and a port
+ // "unix/:-1" corresponds to "/tmp/.font-unix/fs-1".
//
if (strncmp("unix/:", path, 6) == 0)
1500_all_propagate-optflags-to-subcompone.full+lite.patch
1600_nxcomp-handle-launchd-socket-in-Auth.full+lite.patch
1610_nxcomp-harcode-some-UNIX-socket-path.full+lite.patch
9900-dxpc-license-history.full+lite.patch
0016_nx-X11_install-location.debian.patch
0102_xserver-xext_set-securitypolicy-path.debian.patch
Markdown is supported
0% or
You are about to add 0 people to the discussion. Proceed with caution.
Finish editing this message first!
Please register or to comment